Overview — FracAbility 0.1.0 documentation

Skip to main content
`Ctrl`+`K`

# Overview

FracAbility is a Python toolbox that can be used to analyse fracture networks in digitalized rock outcrops.

These are the main features available :

- Shapefile importing support

- Rapid topology analysis and identification of I,Y,X and U nodes

- Fracture network backbone(s) identification

- Statistical analysis tools:

    - Empirical CDF and SF calculation

    - Distribution fitting

    - Statistical model testing

- Plotting tools:

    - Network objects plotting using matplotlib or vtk

    - Ternary node plot

    - Rose diagram

    - Statistical plotting

The name FracAbility recalls the reliability library that inspired and helped in the creation of this project.

# Documentation contents

## Quickstart & Theory

- Quickstart for FracAbility
  - Installation and upgrading
  - A quick example
- Introduction and scope of the FracAbility library.
  - Theory index
- Recommended resources
  - Textbooks
  - Articles
  - Software
  - Online resources

## Tutorials

- Tutorials reference
  - Creating a FractureNetwork object
  - Defining the topology
  - Plotting

## API

- API Reference
  - Entities
  - Plotting options
  - Statistic Operations

## Glossary

- Glossary

# Library status information

Deployment |  |
GitHub |  |
Citation |  |
License |  |
Community |  |